⚠ WARNING, USING THIS CRATE IS NOT RECOMMENDED YET ⚠
The fowlhouse_bay crate provides an easy to use tui client. You can create windows and attach messages to these windows using channels. So, different parts of your software, can send messages to different text based windows on the same terminal.
Example
The following ASCII art example should illustrate how a possible tui could look like. The windows ‘Logfile’ and ‘Ping’ where created using this library and the software using it has sent messages to each of the windows. The user executing the software types the string ‘command x y’ which will be sent to the software using this library through channels.
┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
┃ PowerShell _ □ x ┃
┏━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┓
┃╔Logfile:═════════════════════╗╔Ping:══════════════════════╗┃
┃║loading resource file ║║ping ║┃
┃║successfully created item xy ║║pong ║┃
┃╚═════════════════════════════╝║ping ║┃
┃ ╚═══════════════════════════╝┃
┃STDIN:~$ command x y ┃
┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛Modules
- error
- This module specifies the error types returned by the
Termstruct methods. - window
- This module specifies the
Windowstruct, which represents a single window on the tui generated byTerm.
Structs
- Term
- Term is a tui client.
Constants
- MAX_
MESSAGES_ PER_ CHANNEL - There is a
std::vec::Vec<String>assigned to each channel. The vecs capacity is set to the value of this const. The implementation enforces, that the maximum amount ofStrings in the vec equals the value of this const.